@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
 # Copyright (c) 2015 Mirantis, Inc.
 # All Rights Reserved.
@@ -219,7 +219,7 @@ def main():
 
     # Run consumer
     print_with_time("Consumer was successfully run.")
-    while(True):
+    while True:
         messages = pop_zaqar_messages(
             zaqarclientwrapper.ZAQARCLIENT, CONF.zaqar.zaqar_queues)
         if not messages:
