@@ -94,9 +94,8 @@ class ShareNetworkController(wsgi.Controller, wsgi.AdminActionsMixin):
         except exception.ShareNetworkNotFound as e:
             raise exc.HTTPNotFound(explanation=e.msg)
 
-        share_instances = (
-            db_api.share_instances_get_all_by_share_network(context, id)
-        )
+        share_instances = db_api.share_instance_get_all_by_share_network(
+            context, id)
         if share_instances:
             msg = _("Can not delete share network %(id)s, it has "
                     "%(len)s share(s).") % {'id': id,
@@ -143,11 +142,11 @@ class ShareNetworkController(wsgi.Controller, wsgi.AdminActionsMixin):
                     id,
                     security_service['id'])
             except Exception:
-                LOG.exception(
-                    "Failed to delete security association of network "
-                    "{net_id} and security service "
-                    "{sec_id}".format(net_id=id,
-                                      sec_id=security_service['id']))
+                msg = ("Failed to delete security association of network "
+                       "{net_id} and security service "
+                       "{sec_id}".format(net_id=id,
+                                         sec_id=security_service['id']))
+                LOG.exception(msg)
 
         db_api.share_network_delete(context, id)
 
