@@ -62,8 +62,10 @@ SHARE_ACCESS_RESOURCE_TYPE = 'access_rule'
 # Access rule states
 ACCESS_STATE_QUEUED_TO_APPLY = 'queued_to_apply'
 ACCESS_STATE_QUEUED_TO_DENY = 'queued_to_deny'
+ACCESS_STATE_QUEUED_TO_UPDATE = 'queued_to_update'
 ACCESS_STATE_APPLYING = 'applying'
 ACCESS_STATE_DENYING = 'denying'
+ACCESS_STATE_UPDATING = 'updating'
 ACCESS_STATE_ACTIVE = 'active'
 ACCESS_STATE_ERROR = 'error'
 ACCESS_STATE_DELETED = 'deleted'
@@ -92,8 +94,10 @@ STATUS_NETWORK_CHANGE = 'network_change'
 ACCESS_RULES_STATES = (
     ACCESS_STATE_QUEUED_TO_APPLY,
     ACCESS_STATE_QUEUED_TO_DENY,
+    ACCESS_STATE_QUEUED_TO_UPDATE,
     ACCESS_STATE_APPLYING,
     ACCESS_STATE_DENYING,
+    ACCESS_STATE_UPDATING,
     ACCESS_STATE_ACTIVE,
     ACCESS_STATE_ERROR,
     ACCESS_STATE_DELETED,
