@@ -58,6 +58,8 @@ class RequestContext(context.RequestContext):
             self.is_admin = policy.check_is_admin(self)
         elif self.is_admin and 'admin' not in self.roles:
             self.roles.append('admin')
+        # a "service" user's token will contain "service_roles"
+        self.is_service = kwargs.get('service_roles') or False
         self.read_deleted = read_deleted
         self.remote_address = remote_address
         if not timestamp:
@@ -108,7 +110,7 @@ class RequestContext(context.RequestContext):
             project_id=values.get('project_id'),
             project_name=values.get('project_name'),
             domain_id=values.get('domain_id'),
-            read_deleted=values.get('read_deleted'),
+            read_deleted=values.get('read_deleted', 'no'),
             remote_address=values.get('remote_address'),
             timestamp=values.get('timestamp'),
             quota_class=values.get('quota_class'),
