@@ -72,6 +72,7 @@ class Service(BASE, ManilaBase):
     availability_zone_id = Column(String(36),
                                   ForeignKey('availability_zones.id'),
                                   nullable=True)
+    ensuring = Column(Boolean, default=False)
 
     availability_zone = orm.relationship(
         "AvailabilityZone",
@@ -427,6 +428,11 @@ class ShareInstance(BASE, ManilaBase):
         primaryjoin='and_('
                     'ShareInstance.share_type_id == ShareTypes.id, '
                     'ShareTypes.deleted == "False")')
+    share = orm.relationship(
+        'Share',
+        foreign_keys=share_id,
+        primaryjoin='ShareInstance.share_id == Share.id'
+    )
 
 
 class ShareInstanceExportLocations(BASE, ManilaBase):
@@ -1119,6 +1125,8 @@ class ShareServer(BASE, ManilaBase):
         Boolean, nullable=False, default=False)
     network_allocation_update_support = Column(
         Boolean, nullable=False, default=False)
+    share_replicas_migration_support = Column(
+        Boolean, nullable=False, default=False)
     status = Column(Enum(
         constants.STATUS_INACTIVE, constants.STATUS_ACTIVE,
         constants.STATUS_ERROR, constants.STATUS_DELETING,
@@ -1142,9 +1150,11 @@ class ShareServer(BASE, ManilaBase):
                     'ShareInstance.deleted == "False")')
 
     share_groups = orm.relationship(
-        "ShareGroup", backref='share_server', primaryjoin='and_('
-        'ShareServer.id == ShareGroup.share_server_id,'
-        'ShareGroup.deleted == "False")')
+        "ShareGroup",
+        backref='share_server',
+        primaryjoin='and_('
+                    'ShareServer.id == ShareGroup.share_server_id,'
+                    'ShareGroup.deleted == "False")')
 
     _backend_details = orm.relationship(
         "ShareServerBackendDetails",
@@ -1598,7 +1608,9 @@ def get_aggregated_access_rules_state(instance_mappings):
         order = (constants.ACCESS_STATE_ERROR,
                  constants.ACCESS_STATE_DENYING,
                  constants.ACCESS_STATE_QUEUED_TO_DENY,
+                 constants.ACCESS_STATE_QUEUED_TO_UPDATE,
                  constants.ACCESS_STATE_QUEUED_TO_APPLY,
+                 constants.ACCESS_STATE_UPDATING,
                  constants.ACCESS_STATE_APPLYING,
                  constants.ACCESS_STATE_ACTIVE)
 
