@@ -29,6 +29,8 @@ from oslo_config import cfg
 import oslo_messaging as messaging
 from oslo_messaging.rpc import dispatcher
 from oslo_serialization import jsonutils
+from oslo_utils import importutils
+profiler = importutils.try_import('osprofiler.profiler')
 
 import manila.context
 import manila.exception
@@ -115,9 +117,24 @@ class RequestContextSerializer(messaging.Serializer):
         return self._base.deserialize_entity(context, entity)
 
     def serialize_context(self, context):
-        return context.to_dict()
+        _context = context.to_dict()
+        if profiler is not None:
+            prof = profiler.get()
+            if prof:
+                trace_info = {
+                    "hmac_key": prof.hmac_key,
+                    "base_id": prof.get_base_id(),
+                    "parent_id": prof.get_id()
+                }
+                _context.update({"trace_info": trace_info})
+        return _context
 
     def deserialize_context(self, context):
+        trace_info = context.pop("trace_info", None)
+        if trace_info:
+            if profiler is not None:
+                profiler.init(**trace_info)
+
         return manila.context.RequestContext.from_dict(context)
 
 
@@ -128,10 +145,9 @@ def get_transport_url(url_str=None):
 def get_client(target, version_cap=None, serializer=None):
     assert TRANSPORT is not None
     serializer = RequestContextSerializer(serializer)
-    return messaging.RPCClient(TRANSPORT,
-                               target,
-                               version_cap=version_cap,
-                               serializer=serializer)
+    return messaging.get_rpc_client(
+        TRANSPORT, target, version_cap=version_cap,
+        serializer=serializer)
 
 
 def get_server(target, endpoints, serializer=None):
