@@ -132,7 +132,6 @@ class Service(service.Service):
         self.saved_args, self.saved_kwargs = args, kwargs
         self.coordinator = coordination
 
-        setup_profiler(binary, host)
         self.rpcserver = None
 
     def start(self):
@@ -141,6 +140,7 @@ class Service(service.Service):
                  {'topic': self.topic, 'version_string': version_string})
         self.model_disconnected = False
         ctxt = context.get_admin_context()
+        setup_profiler(self.binary, self.host)
 
         try:
             service_ref = db.service_get_by_args(ctxt,
@@ -352,7 +352,7 @@ class WSGIService(service.ServiceBase):
         if not rpc.initialized():
             rpc.init(CONF)
         self.app = self.loader.load_app(name)
-        self.host = getattr(CONF, '%s_listen' % name, "0.0.0.0")
+        self.host = getattr(CONF, '%s_listen' % name, "0.0.0.0")  # nosec B104
         self.port = getattr(CONF, '%s_listen_port' % name, 0)
         self.workers = getattr(CONF, '%s_workers' % name, None)
         self.use_ssl = getattr(CONF, '%s_use_ssl' % name, False)
@@ -362,7 +362,6 @@ class WSGIService(service.ServiceBase):
                 "greater than 1.  Input value ignored.", {'name': name})
             # Reset workers to default
             self.workers = None
-        setup_profiler(name, self.host)
 
         self.server = wsgi.Server(
             CONF,
@@ -403,6 +402,7 @@ class WSGIService(service.ServiceBase):
         :returns: None
 
         """
+        setup_profiler(self.name, self.host)
         if self.manager:
             self.manager.init_host()
         self.server.start()
