@@ -82,6 +82,7 @@ class PowerMaxStorageConnection(driver.StorageConnection):
         self.pool_conf = None
         self.reserved_percentage = None
         self.reserved_snapshot_percentage = None
+        self.reserved_share_extend_percentage = None
         self.driver_handles_share_servers = True
         self.port_conf = None
         self.ipv6_implemented = True
@@ -600,6 +601,11 @@ class PowerMaxStorageConnection(driver.StorageConnection):
         if self.reserved_snapshot_percentage is None:
             self.reserved_snapshot_percentage = self.reserved_percentage
 
+        self.reserved_share_extend_percentage = config.safe_get(
+            'reserved_share_extend_percentage')
+        if self.reserved_share_extend_percentage is None:
+            self.reserved_share_extend_percentage = self.reserved_percentage
+
         self.manager = manager.StorageObjectManager(config)
         self.port_conf = config.safe_get('powermax_ethernet_ports')
 
@@ -650,6 +656,8 @@ class PowerMaxStorageConnection(driver.StorageConnection):
                     'reserved_percentage': self.reserved_percentage,
                     'reserved_snapshot_percentage':
                         self.reserved_snapshot_percentage,
+                    'reserved_share_extend_percentage':
+                        self.reserved_share_extend_percentage,
                     'snapshot_support': True,
                     'create_share_from_snapshot_support': True,
                     'revert_to_snapshot_support': False,
