@@ -15,7 +15,6 @@
 
 from oslo_config import cfg
 from oslo_log import log
-import six
 
 from manila.tests.integrated import integrated_helpers
 
@@ -34,6 +33,7 @@ class ExtensionsTest(integrated_helpers._IntegratedTestBase):
     def test_get_foxnsocks(self):
         """Simple check that fox-n-socks works."""
         response = self.api.api_request('/foxnsocks')
-        foxnsocks = response.read()
+        foxnsocks = response.text
         LOG.debug("foxnsocks: %s.", foxnsocks)
-        self.assertEqual(six.b('Try to say this Mr. Knox, sir...'), foxnsocks)
+        self.assertEqual('Try to say this Mr. Knox, sir...',
+                         foxnsocks)
