@@ -14,9 +14,9 @@
 #    under the License.
 
 from os import path
+from unittest import mock
 import yaml
 
-import mock
 from oslo_log import log
 
 LOG = log.getLogger(__name__)
@@ -31,5 +31,6 @@ def load_yaml(file_name):
         LOG.debug('Loaded yaml mock objects from %s.', yaml_file)
     return res
 
+
 patch_find_ports_by_mtu = mock.patch('manila.share.drivers.dell_emc.plugins.'
                                      'unity.utils.find_ports_by_mtu')
