@@ -192,12 +192,18 @@ class VASTShareDriverTestCase(unittest.TestCase):
                 mock_rest.views.ensure.assert_called_once_with(
                     name="fakeid", path="/fake/manila-fakeid", policy_id=1
                 )
-                self.assertDictEqual(
+                self.assertListEqual(
                     location,
-                    {
-                        'path': '1.1.1.0:/fake/manila-fakeid',
-                        'is_admin_only': False
-                    }
+                    [
+                        {
+                            'path': '1.1.1.0:/fake/manila-fakeid',
+                            'is_admin_only': False
+                        },
+                        {
+                            'path': '1.1.1.1:/fake/manila-fakeid',
+                            'is_admin_only': False
+                        },
+                    ]
                 )
                 if not policy:
                     mock_rest.views.update.assert_called_once_with(
@@ -232,6 +238,7 @@ class VASTShareDriverTestCase(unittest.TestCase):
             share,
             access_rules,
             None,
+            None,
             None
         )
         self.assertIsNone(res)
@@ -250,7 +257,7 @@ class VASTShareDriverTestCase(unittest.TestCase):
         with mock.patch.object(self._driver, "rest", mock_rest):
             with self.assertRaises(exception.ManilaException) as exc:
                 self._driver.update_access(
-                    self._context, share, access_rules, None, None
+                    self._context, share, access_rules, None, None, None
                 )
             self.assertIn("Policy not found", str(exc.exception))
 
@@ -279,6 +286,7 @@ class VASTShareDriverTestCase(unittest.TestCase):
                 share,
                 access_rules,
                 None,
+                None,
                 None
             )
 
@@ -313,6 +321,7 @@ class VASTShareDriverTestCase(unittest.TestCase):
                 share,
                 access_rules,
                 None,
+                None,
                 None
             )
 
@@ -354,6 +363,7 @@ class VASTShareDriverTestCase(unittest.TestCase):
                 None,
                 None,
                 delete_rules,
+                None,
             )
 
         expected_ro = set(ro)
@@ -383,7 +393,7 @@ class VASTShareDriverTestCase(unittest.TestCase):
         ]
         with mock.patch.object(self._driver, "rest", mock_rest):
             failed_rules = self._driver.update_access(
-                self._context, share, None, None, delete_rules
+                self._context, share, None, None, delete_rules, None
             )
 
         expected_rw = set(rw)
@@ -419,6 +429,7 @@ class VASTShareDriverTestCase(unittest.TestCase):
                 share,
                 access_rules,
                 None,
+                None,
                 None
             )
             kw = mock_rest.view_policies.update.call_args.kwargs
@@ -463,6 +474,7 @@ class VASTShareDriverTestCase(unittest.TestCase):
                 None,
                 None,
                 delete_rules,
+                None
             )
             kw = mock_rest.view_policies.update.call_args.kwargs
             self.assertEqual(kw["name"], "fakeid")
@@ -515,6 +527,7 @@ class VASTShareDriverTestCase(unittest.TestCase):
                 share,
                 access_rules,
                 None,
+                None,
                 None
             )
             kw = mock_rest.view_policies.update.call_args.kwargs
